Index: trunk/src/lib/gui/gl_gui/glgui_slider.h
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_slider.h	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_slider.h	(revision 5365)
@@ -1,10 +1,10 @@
 /*!
- * @file glgui_.h
+ * @file glgui_slider.h
  * The gl_ widget of th openglGUI
  *
  */
 
-#ifndef _GLGUI__H
-#define _GLGUI__H
+#ifndef _GLGUI_SLIDER_H
+#define _GLGUI_SLIDER_H
 
 #include "base_object.h"
@@ -16,9 +16,9 @@
  *
  */
-class GLGui : public GLGui {
+class GLGuiSlider : public GLGuiSlider {
 
  public:
-  GLGui();
-  virtual ~GLGui();
+  GLGuiSlider();
+  virtual ~GLGuiSlider();
 
   void init();
@@ -30,3 +30,3 @@
 };
 
-#endif /* _GLGUI__H */
+#endif /* _GLGUI_SLIDER_H */
Index: trunk/src/lib/gui/gl_gui/glgui_textfield.h
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_textfield.h	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_textfield.h	(revision 5365)
@@ -1,14 +1,16 @@
 /*!
- * @file glgui_.h
+ * @file glgui_textfield.h
  * The gl_ widget of th openglGUI
  *
  */
 
-#ifndef _GLGUI__H
-#define _GLGUI__H
+#ifndef _GLGUI_TEXTFIELD_H
+#define _GLGUI_TEXTFIELD_H
 
-#include "base_object.h"
+#include "glgui_widget.h"
 
 // FORWARD DECLARATION
+class Text;
+template<class T> class tList;
 
 //! This is part of the openglGUI class
@@ -16,9 +18,9 @@
  *
  */
-class GLGui : public GLGui {
+class GLGuiTextfield : public GLGuiWidget {
 
  public:
-  GLGui();
-  virtual ~GLGui();
+  GLGuiTextfield();
+  virtual ~GLGuiTextfield();
 
   void init();
@@ -27,4 +29,5 @@
 
  private:
+  tList<Text>*      textLines;
 
 };
Index: trunk/src/lib/gui/gl_gui/glgui_widget.h
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_widget.h	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_widget.h	(revision 5365)
@@ -8,6 +8,8 @@
 
 #include "element_2d.h"
+#include "glincl.h"
 
 // FORWARD DECLARATION
+class Material;
 
 //! This is part of the openglGUI class
@@ -16,5 +18,4 @@
  */
 class GLGuiWidget : public Element2D {
-
  public:
   GLGuiWidget();
@@ -31,4 +32,12 @@
 
  private:
+  bool                  managed;          //!< if this GUI-element should be managed. true means it gets deleted with the deletion of it's parent.
+  bool                  focusable;        //!< If it can receive focus.
+  bool                  clickable;        //!< if it can be clicked upon.
+
+  Material*             backGround;
+  GLuint                renderModel;
+
+
 
 };

Index: trunk/src/lib/gui/gl_gui/glgui_bar.cc
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_bar.cc	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_bar.cc	(revision 5365)
@@ -23,5 +23,5 @@
  * standard constructor
 */
-GLGui::GLGui ()
+GLGuiBar::GLGuiBar ()
 {
   this->init();
@@ -33,5 +33,5 @@
  * standard deconstructor
 */
-GLGui::~GLGui()
+GLGuiBar::~GLGuiBar()
 {
 
@@ -41,14 +41,14 @@
  * initializes the GUI-element
  */
-GLGui::init()
+GLGuiBar::init()
 {
-  this->setClassID(CL_GLGUI_, "GLGui");
+  this->setClassID(CL_GLGUI_BAR, "GLGuiBar");
 
 }
 
 /**
  * draws the GLGui
  */
-void GLGui::draw()
+void GLGuiBar::draw()
 {
 
@@ -41,14 +41,14 @@
 
 /**
- * draws the GLGui
+ * draws the GLGuiBar
  */
Index: trunk/src/lib/gui/gl_gui/glgui_bar.h
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_bar.h	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_bar.h	(revision 5365)
@@ -1,24 +1,24 @@
 /*!
- * @file glgui_.h
+ * @file glgui_bar.h
  * The gl_ widget of th openglGUI
  *
  */
 
-#ifndef _GLGUI__H
-#define _GLGUI__H
+#ifndef _GLGUI_BAR_H
+#define _GLGUI_BAR_H
 
-#include "base_object.h"
+#include "glgui_widget.h"
 
 // FORWARD DECLARATION
 
 //! This is part of the openglGUI class
 /**
  *
  */
-class GLGui : public GLGui {
+class GLGuiBar : public GLGuiWidget {
 
  public:
-  GLGui();
-  virtual ~GLGui();
+  GLGuiBar();
+  virtual ~GLGuiBar();
 
   void init();
@@ -1,24 +1,24 @@
 // FORWARD DECLARATION
 
-//! This is part of the openglGUI class
+//! This is Bar part of the openglGUI class
 /**
  *
Index: trunk/src/lib/gui/gl_gui/glgui_slider.cc
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_slider.cc	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_slider.cc	(revision 5365)
@@ -16,5 +16,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_GUI
 
-#include "glgui_.h"
+#include "glgui_slider.h"
 
 using namespace std;
@@ -23,5 +23,5 @@
  * standard constructor
 */
-GLGui::GLGui ()
+GLGuiSlider::GLGuiSlider ()
 {
   this->init();
@@ -33,5 +33,5 @@
  * standard deconstructor
 */
-GLGui::~GLGui()
+GLGuiSlider::~GLGuiSlider()
 {
 
@@ -41,14 +41,14 @@
  * initializes the GUI-element
  */
-GLGui::init()
+void GLGuiSlider::init()
 {
-  this->setClassID(CL_GLGUI_, "GLGui");
+  this->setClassID(CL_GLGUI_SLIDER, "GLGuiSlider");
 
 }
 
 /**
  * draws the GLGui
  */
-void GLGui::draw()
+void GLGuiSlider::draw()
 {
 
@@ -41,14 +41,14 @@
 
 /**
- * draws the GLGui
+ * draws the GLGuiSlider
  */
Index: trunk/src/lib/gui/gl_gui/glgui_text.cc
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_text.cc	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_text.cc	(revision 5365)
@@ -16,5 +16,7 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_GUI
 
-#include "glgui_.h"
+#include "glgui_text.h"
+
+#include "text.h"
 
 using namespace std;
@@ -23,5 +25,5 @@
  * standard constructor
 */
-GLGui::GLGui ()
+GLGuiText::GLGuiText ()
 {
   this->init();
@@ -33,5 +35,5 @@
  * standard deconstructor
 */
-GLGui::~GLGui()
+GLGuiText::~GLGuiText()
 {
 
@@ -41,14 +43,14 @@
  * initializes the GUI-element
  */
-GLGui::init()
+void GLGuiText::init()
 {
-  this->setClassID(CL_GLGUI_, "GLGui");
+  this->setClassID(CL_GLGUI_, "GLGuiText");
 
 }
 
 /**
  * draws the GLGui
  */
-void GLGui::draw()
+void GLGuiText::draw()
 {
 
@@ -41,14 +43,14 @@
 
 /**
- * draws the GLGui
+ * draws the GLGuiText
  */
Index: trunk/src/lib/gui/gl_gui/glgui_text.h
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_text.h	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_text.h	(revision 5365)
@@ -1,14 +1,15 @@
 /*!
  * @file glgui_.h
  * The gl_ widget of th openglGUI
  *
  */
 
-#ifndef _GLGUI__H
-#define _GLGUI__H
+#ifndef _GLGUI_TEXT_H
+#define _GLGUI_TEXT_H
 
-#include "base_object.h"
+#include "glgui_widget.h"
 
 // FORWARD DECLARATION
+class Text;
 
 //! This is part of the openglGUI class
@@ -16,9 +17,9 @@
  *
  */
-class GLGui : public GLGui {
+class GLGuiText : public GLWidget {
 
  public:
-  GLGui();
-  virtual ~GLGui();
+  GLGuiText();
+  virtual ~GLGuiText();
 
   void init();
@@ -27,6 +28,6 @@
 
  private:
-
+  Text*             text;
 };
 
-#endif /* _GLGUI__H */
+#endif /* _GLGUI_TEXT_H */
@@ -1,14 +1,15 @@
 /*!
- * @file glgui_.h
- * The gl_ widget of th openglGUI
+ * @file glgui_text.h
+ * The gl_TEXT widget of th openglGUI
  *
  */
Index: trunk/src/lib/gui/gl_gui/glgui_textfield.cc
===================================================================
--- trunk/src/lib/gui/gl_gui/glgui_textfield.cc	(revision 5364)
+++ trunk/src/lib/gui/gl_gui/glgui_textfield.cc	(revision 5365)
@@ -16,5 +16,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_GUI
 
-#include "glgui_.h"
+#include "glgui_textfield_.h"
 
 using namespace std;
@@ -23,5 +23,5 @@
  * standard constructor
 */
-GLGui::GLGui ()
+GLGuiTextfield::GLGuiTextfield ()
 {
   this->init();
@@ -33,5 +33,5 @@
  * standard deconstructor
 */
-GLGui::~GLGui()
+GLGuiTextfield::~GLGuiTextfield()
 {
 
@@ -41,14 +41,14 @@
  * initializes the GUI-element
  */
-GLGui::init()
+void GLGuiTextfield::init()
 {
-  this->setClassID(CL_GLGUI_, "GLGui");
+  this->setClassID(CL_GLGUI_, "GLGuiTextfield");
 
 }
 
 /**
  * draws the GLGui
  */
-void GLGui::draw()
+void GLGuiTextfield::draw()
 {
 
@@ -41,14 +41,14 @@
 
 /**
- * draws the GLGui
+ * draws the GLGuiTextfield
  */